@@ -1,7 +1,7 @@
 """
 Type annotations for ssm service literal definitions.
 
-[Open documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ssm/literals.html)
+[Open documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ssm/literals/)
 
 Usage::
 
@@ -156,6 +156,7 @@ __all__ = (
     "ResourceServiceName",
     "PaginatorName",
     "WaiterName",
+    "RegionName",
 )
 
 
@@ -362,6 +363,7 @@ OperatingSystemType = Literal[
     "ORACLE_LINUX",
     "RASPBIAN",
     "REDHAT_ENTERPRISE_LINUX",
+    "ROCKY_LINUX",
     "SUSE",
     "UBUNTU",
     "WINDOWS",
@@ -870,3 +872,27 @@ PaginatorName = Literal[
     "list_resource_data_sync",
 ]
 WaiterName = Literal["command_executed"]
+RegionName = Literal[
+    "af-south-1",
+    "ap-east-1",
+    "ap-northeast-1",
+    "ap-northeast-2",
+    "ap-northeast-3",
+    "ap-south-1",
+    "ap-southeast-1",
+    "ap-southeast-2",
+    "ap-southeast-3",
+    "ca-central-1",
+    "eu-central-1",
+    "eu-north-1",
+    "eu-south-1",
+    "eu-west-1",
+    "eu-west-2",
+    "eu-west-3",
+    "me-south-1",
+    "sa-east-1",
+    "us-east-1",
+    "us-east-2",
+    "us-west-1",
+    "us-west-2",
+]
